@@ -18,12 +18,14 @@
 #  along with quality-result-gui. If not, see <https://www.gnu.org/licenses/>.
 
 
-__version__ = "1.1.2"
+__version__ = "1.1.5"
 
 
-from enum import Enum
+from enum import Enum, auto
 
 
 class SelectionType(Enum):
-    RightClick = 1
-    Other = 2
+    LeftClick = auto()
+    RightClick = auto()
+    Keyboard = auto()
+    Other = auto()
