@@ -19,9 +19,10 @@
 
 import logging
 from enum import Enum, auto
-from typing import List, Optional
+from typing import TYPE_CHECKING, List, Optional
 
 from qgis.PyQt.QtCore import QObject, QThread, QTimer, pyqtSignal, pyqtSlot
+from qgis_plugin_tools.tools.i18n import tr
 
 from quality_result_gui.api.quality_api_client import (
     QualityResultClient,
@@ -29,6 +30,9 @@ from quality_result_gui.api.quality_api_client import (
     QualityResultServerError,
 )
 
+if TYPE_CHECKING:
+    from quality_result_gui.api.types.quality_error import QualityErrorsByPriority
+
 BACKGROUND_POLL_INTERVAL = 10 * 1000
 
 LOGGER = logging.getLogger(__name__)
@@ -41,14 +45,18 @@ class CheckStatus(Enum):
     RESULT_FAILED = auto()
 
 
+CHECK_STATUS_LABELS = {
+    CheckStatus.CHECKING: tr("Checking for quality result updates"),
+    CheckStatus.RESULT_ONGOING: tr("Quality check is in progress"),
+    CheckStatus.RESULT_FAILED: tr("Quality result update failed"),
+    CheckStatus.RESULT_UPDATED: tr("Quality results are up to date"),
+}
+
+
 class PollingWorker(QObject):
     status_changed = pyqtSignal(CheckStatus)
     results_received = pyqtSignal(list)
 
-    _timer: Optional[QTimer]
-    _poll_interval: int
-    _last_ready_run_id: Optional[int]
-
     def __init__(
         self,
         api_client: QualityResultClient,
@@ -56,19 +64,23 @@ class PollingWorker(QObject):
         poll_interval: int = BACKGROUND_POLL_INTERVAL,
     ) -> None:
         super().__init__(parent)
-        self._timer = None
+        self._timer: Optional[QTimer] = None
         self._poll_interval = poll_interval
-        self._last_ready_run_id = None
         self._api_client = api_client
 
     @pyqtSlot()
     def start(self) -> None:
         if self._timer is not None:
             self._timer.stop()
+
+        # Run every x seconds
         self._timer = QTimer(self)
         self._timer.timeout.connect(self._check_api)
         self._timer.start(self._poll_interval)
 
+        # For the first time run right now since timer triggers it after x seconds
+        self._check_api()
+
     @pyqtSlot()
     def _check_api(self) -> None:
         self.status_changed.emit(CheckStatus.CHECKING)
@@ -90,11 +102,6 @@ class PollingWorker(QObject):
 
 
 class BackgroundQualityResultsFetcher(QObject):
-    _thread: Optional[QThread]
-    _worker: Optional[PollingWorker]
-    _poll_interval: int
-
-    _check_requested = pyqtSignal()
     status_changed = pyqtSignal(CheckStatus)
     results_received = pyqtSignal(list)
 
@@ -105,8 +112,8 @@ class BackgroundQualityResultsFetcher(QObject):
         poll_interval: int = BACKGROUND_POLL_INTERVAL,
     ) -> None:
         super().__init__(parent)
-        self._thread = None
-        self._worker = None
+        self._thread: Optional[QThread] = None
+        self._worker: Optional[PollingWorker] = None
         self._poll_interval = poll_interval
         self._api_client = api_client
 
@@ -114,7 +121,6 @@ class BackgroundQualityResultsFetcher(QObject):
     def set_checks_enabled(self, enabled: bool) -> None:
         if enabled:
             self.start()
-            self._check_requested.emit()
         else:
             self.stop()
 
@@ -123,7 +129,9 @@ class BackgroundQualityResultsFetcher(QObject):
         self.status_changed.emit(status)
 
     @pyqtSlot(list)
-    def _worker_results_received(self, results: List) -> None:
+    def _worker_results_received(
+        self, results: List["QualityErrorsByPriority"]
+    ) -> None:
         self.results_received.emit(results)
 
     @pyqtSlot()
@@ -132,17 +140,18 @@ class BackgroundQualityResultsFetcher(QObject):
         self._thread = QThread(self)
         self._worker = PollingWorker(self._api_client, None, self._poll_interval)
         self._worker.moveToThread(self._thread)
+
+        self._thread.finished.connect(self._worker.deleteLater)
+        self._thread.started.connect(self._worker.start)
+
         self._worker.status_changed.connect(self._worker_status_changed)
         self._worker.results_received.connect(self._worker_results_received)
-        self._check_requested.connect(self._worker._check_api)
-        self._thread.started.connect(self._worker.start)
-        self._thread.finished.connect(self._worker.deleteLater)
-        self._thread.finished.connect(self._thread.deleteLater)
+
         self._thread.start()
 
     @pyqtSlot()
     def stop(self) -> None:
-        if self._thread is not None:
-            if self._thread.isRunning():
-                self._thread.quit()
-            self._thread = None
+        if self._thread and self._thread.isRunning():
+            self._thread.quit()
+            self._thread.wait()
+        self._thread = None
